Logika systému postavenom na jadre linux 6. časť

11.10 | 00:14 | redhawk1975 | redhawk1975
Seriál: linux

Dnes si povieme, ako sa dostať k informáciam, ktoré zjedodušia prácu s Linuxom.

Naviažem priamo na prvý diel a vysvetlím ako som, v termináli, našiel všetko a ako to môže pomôcť pokiaľ nejde sieť alebo je to ostrovný systém.

 V prvom rade si treba zapamätať jeden príkaz a jeden prepínač.

Tým príkazom je man.

Príkaz man (skratka pre manual) slúži v Linuxe na zobrazenie manuálových stránok — oficiálnej systémovej dokumentácie k príkazom, nástrojom, konfiguračným súborom a systémovým funkciám.

Napríklad zadaním man ls zobrazí detailný popis príkazu ls, zoznam všetkých jeho prepínačov (voľných parametrov) a ich význam.

RH: Rovnako funguje aj prepínač -h -help alebo -? ten ale v niektorých prípadoch, napríklad pri ls nefunguje.

$ lsusb -h
Usage: lsusb [options]...
List USB devices
  -v, --verbose
      Increase verbosity (show descriptors)
  -s [[bus]:][devnum]
      Show only devices with specified device and/or
      bus numbers (in decimal)
  -d vendor:[product]
      Show only devices with the specified vendor and
      product ID numbers (in hexadecimal)
  -D device
      Selects which device lsusb will examine
  -t, --tree
      Dump the physical USB device hierarchy as a tree
  -V, --version
      Show version of program
  -h, --help
      Show usage and help
fjs@futro-s920:~
$ 

Navigácia v manuáli

Dokument sa štandardne otvára v textovom prehliadači (zvyčajne less), kde sa pohybuješ pomocou klávesnice:

man -k <kľúčové_slovo>  – prehadá databázu manuálov a vypíše príkazy, ktoré dané slovo obsahujú v popise. Hodí sa, keď si nespomínaš na presný názov príkazu.
man man – zobrazí manuál k samotnému príkazu man

A tam nájdete všetko k systému na kitorom pracujete.

Prepínač za príkazom, ktorý je dobré si zapamätať je -h.

V menšom funguje ako man ku konkrétnemu príkazu.

Pri mnohých aplikáciách, skriptoch a neštandardných nástrojoch znamená -h = help.

Po jeho pridaní príkaz nevykoná svoju hlavnú prácu, ale vypíše stručnú nápovedu, syntax použitia (usage) a prehľad najdôležitejších prepínačov. Býva to rýchlejšia alternatíva k otváraniu celého manuálu cez man.

Ako príklad čiastočný výpis z fastfetch -h

$ fastfetch -h
Fastfetch is a neofetch-like tool for fetching system information and displaying them in a pretty way
Usage: fastfetch <?options>
​Informative options:
  -h, --help <?command>                      Show this message, or help for a specific command
  -v, --version                              Show the full version of fastfetch
      --version-raw                          Show the raw version string (major.minor.patch)
      --list-config-paths                    List search paths of config files
      --list-data-paths                      List search paths of presets and logos
      --list-logos                           List available logos
      --list-modules                         List available modules
      --list-presets                         List presets fastfetch knows about
      --list-features                        List the supported features fastfetch was compiled with
      --print-logos                          Print available logos
      --print-structure                      Print the default structure
      --format <enum>                        Set output format

Druhým významom prepínaču -h je výpis v ľudsky pochopiteľnom, čitateľnom formáte (Human-Readable ).

Pri nástrojoch, ktoré pracujú so súbormi, diskovým priestorom alebo pamäťou, znamená -h = human-readable.

Namiesto zobrazenia veľkostí v surových bajtoch (napr. 1048576) prepočíta hodnoty na prehľadné jednotky ako K (Kilobajty), M (Megabajty) alebo G (Gigabajty).

Príklady:

df -h – zobrazí voľné miesto na diskových oddieloch v GB/MB.
du -sh * – vypíše celkovú veľkosť adresárov v čitateľnej podobe.
ls -lh – vypíše detailný zoznam súborov s veľkosťou (napr. 4.2M namiesto 4404019).
free -h – zobrazí využitie RAM a SWAP pamäte v MB/GB.

RH: Pri niektorých špecifických príkazoch má -h odlišný význam. Napríklad v databázových a sieťových klientoch definuje cieľový server (napr. mysql -h 127.0.0.1 -u root alebo pg_dump -h moj-server). Rovnako pri príkaze grep -h potlačí vypisovanie názvov súborov vo výstupe, ak prehľadávaš viacero súborov naraz.

V poslednej časti sa trochu pobavíme.

Logika systému postavenom na jadre linux 1. časť súbory a logická štruktúra systému.
Logika systému postavenom na jadre linux 2. časť pomenovanie zariadení a oprávnenia.
Logika systému postavenom na jadre linux 3. časť init systémy.
Logika systému postavenom na jadre linux 4. časť adresár /etc.
Logika systému postavenom na jadre linux 5. časť ovládače hardvéru.
Logika systému postavenom na jadre linux 6. časť manuál a informácie v systéme.
Logika systému postavenom na jadre linux 7. časť odreagovanie a zaujímavosti

    • RE: Logika systému postavenom na jadre linux 6. časť 12.10 | 06:30
      Avatar kamowski Linux Mint  Používateľ

      👍 tá časť o "help" je pre mňa užitočná, niečo som vedel a používal, niečo nie, ďakujem